==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/CassandraSchemaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.CassandraSchemaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Cosmos DB Cassandra table schema
 * @property clusterKeys List of cluster key.
 * @property columns List of Cassandra table columns.
 * @property partitionKeys List of partition key.
 */
public data class CassandraSchemaArgs(
    public val clusterKeys: Output<List<ClusterKeyArgs>>? = null,
    public val columns: Output<List<ColumnArgs>>? = null,
    public val partitionKeys: Output<List<CassandraPartitionKeyArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.CassandraSchemaArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.CassandraSchemaArgs =
        com.pulumi.azurenative.documentdb.inputs.CassandraSchemaArgs.builder()
            .clusterKeys(
                clusterKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .columns(
                columns?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .partitionKeys(
                partitionKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [CassandraSchemaArgs].
 */
@PulumiTagMarker
public class CassandraSchemaArgsBuilder internal constructor() {
    private var clusterKeys: Output<List<ClusterKeyArgs>>? = null

    private var columns: Output<List<ColumnArgs>>? = null

    private var partitionKeys: Output<List<CassandraPartitionKeyArgs>>? = null

    /**
     * @param value List of cluster key.
     */
    @JvmName("hjlujrgnldfeqcoi")
    public suspend fun clusterKeys(`value`: Output<List<ClusterKeyArgs>>) {
        this.clusterKeys = value
    }

    @JvmName("gblkibigfdxcfyse")
    public suspend fun clusterKeys(vararg values: Output<ClusterKeyArgs>) {
        this.clusterKeys = Output.all(values.asList())
    }

    /**
     * @param values List of cluster key.
     */
    @JvmName("dqmbaxrmcsmiakrc")
    public suspend fun clusterKeys(values: List<Output<ClusterKeyArgs>>) {
        this.clusterKeys = Output.all(values)
    }

    /**
     * @param value List of Cassandra table columns.
     */
    @JvmName("qxehugijajtefdpm")
    public suspend fun columns(`value`: Output<List<ColumnArgs>>) {
        this.columns = value
    }

    @JvmName("dtfkrycwuuvtvpqb")
    public suspend fun columns(vararg values: Output<ColumnArgs>) {
        this.columns = Output.all(values.asList())
    }

    /**
     * @param values List of Cassandra table columns.
     */
    @JvmName("fudilnkjhovowasx")
    public suspend fun columns(values: List<Output<ColumnArgs>>) {
        this.columns = Output.all(values)
    }

    /**
     * @param value List of partition key.
     */
    @JvmName("tuvlgvjjiyklicil")
    public suspend fun partitionKeys(`value`: Output<List<CassandraPartitionKeyArgs>>) {
        this.partitionKeys = value
    }

    @JvmName("nyhwivxqgufyckjf")
    public suspend fun partitionKeys(vararg values: Output<CassandraPartitionKeyArgs>) {
        this.partitionKeys = Output.all(values.asList())
    }

    /**
     * @param values List of partition key.
     */
    @JvmName("svkacgrhyaugrcct")
    public suspend fun partitionKeys(values: List<Output<CassandraPartitionKeyArgs>>) {
        this.partitionKeys = Output.all(values)
    }

    /**
     * @param value List of cluster key.
     */
    @JvmName("srkrhncboqekelgd")
    public suspend fun clusterKeys(`value`: List<ClusterKeyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterKeys = mapped
    }

    /**
     * @param argument List of cluster key.
     */
    @JvmName("jwcdfyupyllmrpat")
    public suspend fun clusterKeys(argument: List<suspend ClusterKeyArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ClusterKeyArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.clusterKeys = mapped
    }

    /**
     * @param argument List of cluster key.
     */
    @JvmName("gvypctjioabbenjd")
    public suspend fun clusterKeys(vararg argument: suspend ClusterKeyArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ClusterKeyArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.clusterKeys = mapped
    }

    /**
     * @param argument List of cluster key.
     */
    @JvmName("duewahyvtktycmtj")
    public suspend fun clusterKeys(argument: suspend ClusterKeyArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ClusterKeyArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.clusterKeys = mapped
    }

    /**
     * @param values List of cluster key.
     */
    @JvmName("gmskeinwyeerbrbr")
    public suspend fun clusterKeys(vararg values: ClusterKeyArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterKeys = mapped
    }

    /**
     * @param value List of Cassandra table columns.
     */
    @JvmName("jgadgbggxfatibgd")
    public suspend fun columns(`value`: List<ColumnArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    /**
     * @param argument List of Cassandra table columns.
     */
    @JvmName("uhfkjkrrajgbrpak")
    public suspend fun columns(argument: List<suspend ColumnArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ColumnArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param argument List of Cassandra table columns.
     */
    @JvmName("jocbjmqyoqjgyrya")
    public suspend fun columns(vararg argument: suspend ColumnArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ColumnArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param argument List of Cassandra table columns.
     */
    @JvmName("wcqqbcbbmnrqbpax")
    public suspend fun columns(argument: suspend ColumnArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ColumnArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param values List of Cassandra table columns.
     */
    @JvmName("yxfrmosagywnmwow")
    public suspend fun columns(vararg values: ColumnArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    /**
     * @param value List of partition key.
     */
    @JvmName("cjlpddikahxnsqkg")
    public suspend fun partitionKeys(`value`: List<CassandraPartitionKeyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partitionKeys = mapped
    }

    /**
     * @param argument List of partition key.
     */
    @JvmName("boqqkiagcsqfptcr")
    public suspend
    fun partitionKeys(argument: List<suspend CassandraPartitionKeyArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            CassandraPartitionKeyArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.partitionKeys = mapped
    }

    /**
     * @param argument List of partition key.
     */
    @JvmName("bomwudcyhfcitkss")
    public suspend fun partitionKeys(
        vararg
        argument: suspend CassandraPartitionKeyArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            CassandraPartitionKeyArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.partitionKeys = mapped
    }

    /**
     * @param argument List of partition key.
     */
    @JvmName("ojifuwvksolgdocr")
    public suspend fun partitionKeys(argument: suspend CassandraPartitionKeyArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(CassandraPartitionKeyArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.partitionKeys = mapped
    }

    /**
     * @param values List of partition key.
     */
    @JvmName("cilhqnlcqdadrbqt")
    public suspend fun partitionKeys(vararg values: CassandraPartitionKeyArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.partitionKeys = mapped
    }

    internal fun build(): CassandraSchemaArgs = CassandraSchemaArgs(
        clusterKeys = clusterKeys,
        columns = columns,
        partitionKeys = partitionKeys,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/CassandraSchemaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.CassandraSchemaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Cosmos DB Cassandra table schema
 * @property clusterKeys List of cluster key.
 * @property columns List of Cassandra table columns.
 * @property partitionKeys List of partition key.
 */
public data class CassandraSchemaArgs(
    public val clusterKeys: Output<List<ClusterKeyArgs>>? = null,
    public val columns: Output<List<ColumnArgs>>? = null,
    public val partitionKeys: Output<List<CassandraPartitionKeyArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.CassandraSchemaArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.CassandraSchemaArgs =
        com.pulumi.azurenative.documentdb.inputs.CassandraSchemaArgs.builder()
            .clusterKeys(
                clusterKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .columns(
                columns?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .partitionKeys(
                partitionKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [CassandraSchemaArgs].
 */
@PulumiTagMarker
public class CassandraSchemaArgsBuilder internal constructor() {
    private var clusterKeys: Output<List<ClusterKeyArgs>>? = null

    private var columns: Output<List<ColumnArgs>>? = null

    private var partitionKeys: Output<List<CassandraPartitionKeyArgs>>? = null

    /**
     * @param value List of cluster key.
     */
    @JvmName("cdiiqcrvhfksoyhq")
    public suspend fun clusterKeys(`value`: Output<List<ClusterKeyArgs>>) {
        this.clusterKeys = value
    }

    @JvmName("imiwtxqrdrpftays")
    public suspend fun clusterKeys(vararg values: Output<ClusterKeyArgs>) {
        this.clusterKeys = Output.all(values.asList())
    }

    /**
     * @param values List of cluster key.
     */
    @JvmName("tgyirvanwunrxsno")
    public suspend fun clusterKeys(values: List<Output<ClusterKeyArgs>>) {
        this.clusterKeys = Output.all(values)
    }

    /**
     * @param value List of Cassandra table columns.
     */
    @JvmName("ruuvrfwhpbtycoja")
    public suspend fun columns(`value`: Output<List<ColumnArgs>>) {
        this.columns = value
    }

    @JvmName("pmtqeevkcdfqhomc")
    public suspend fun columns(vararg values: Output<ColumnArgs>) {
        this.columns = Output.all(values.asList())
    }

    /**
     * @param values List of Cassandra table columns.
     */
    @JvmName("hhshywltiggctvpv")
    public suspend fun columns(values: List<Output<ColumnArgs>>) {
        this.columns = Output.all(values)
    }

    /**
     * @param value List of partition key.
     */
    @JvmName("glbfujlmgfoycisi")
    public suspend fun partitionKeys(`value`: Output<List<CassandraPartitionKeyArgs>>) {
        this.partitionKeys = value
    }

    @JvmName("boissjmbjsdbnpcl")
    public suspend fun partitionKeys(vararg values: Output<CassandraPartitionKeyArgs>) {
        this.partitionKeys = Output.all(values.asList())
    }

    /**
     * @param values List of partition key.
     */
    @JvmName("hqtkosmipepmnyxj")
    public suspend fun partitionKeys(values: List<Output<CassandraPartitionKeyArgs>>) {
        this.partitionKeys = Output.all(values)
    }

    /**
     * @param value List of cluster key.
     */
    @JvmName("slhaiuurraxqhwlh")
    public suspend fun clusterKeys(`value`: List<ClusterKeyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterKeys = mapped
    }

    /**
     * @param argument List of cluster key.
     */
    @JvmName("jbrcwqdphgvdmfsa")
    public suspend fun clusterKeys(argument: List<suspend ClusterKeyArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ClusterKeyArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.clusterKeys = mapped
    }

    /**
     * @param argument List of cluster key.
     */
    @JvmName("bdoflouuxtjvqlvv")
    public suspend fun clusterKeys(vararg argument: suspend ClusterKeyArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ClusterKeyArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.clusterKeys = mapped
    }

    /**
     * @param argument List of cluster key.
     */
    @JvmName("ikfsmfblopchtsis")
    public suspend fun clusterKeys(argument: suspend ClusterKeyArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ClusterKeyArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.clusterKeys = mapped
    }

    /**
     * @param values List of cluster key.
     */
    @JvmName("gddmsjnsogbeqrww")
    public suspend fun clusterKeys(vararg values: ClusterKeyArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterKeys = mapped
    }

    /**
     * @param value List of Cassandra table columns.
     */
    @JvmName("usemnyucpudcoosh")
    public suspend fun columns(`value`: List<ColumnArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    /**
     * @param argument List of Cassandra table columns.
     */
    @JvmName("huxbvwckyqiweskw")
    public suspend fun columns(argument: List<suspend ColumnArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ColumnArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param argument List of Cassandra table columns.
     */
    @JvmName("wkuebhpjhugfiidh")
    public suspend fun columns(vararg argument: suspend ColumnArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ColumnArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param argument List of Cassandra table columns.
     */
    @JvmName("pspvphsipapnyhbh")
    public suspend fun columns(argument: suspend ColumnArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ColumnArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param values List of Cassandra table columns.
     */
    @JvmName("gsrtuqjwsyodyyas")
    public suspend fun columns(vararg values: ColumnArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    /**
     * @param value List of partition key.
     */
    @JvmName("xrxwwhxstmmjqeqr")
    public suspend fun partitionKeys(`value`: List<CassandraPartitionKeyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partitionKeys = mapped
    }

    /**
     * @param argument List of partition key.
     */
    @JvmName("idsovcpeuyuxtxik")
    public suspend
    fun partitionKeys(argument: List<suspend CassandraPartitionKeyArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            CassandraPartitionKeyArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.partitionKeys = mapped
    }

    /**
     * @param argument List of partition key.
     */
    @JvmName("qlsrbnrvrruciedd")
    public suspend fun partitionKeys(
        vararg
        argument: suspend CassandraPartitionKeyArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            CassandraPartitionKeyArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.partitionKeys = mapped
    }

    /**
     * @param argument List of partition key.
     */
    @JvmName("qergkaqwyjltvtmh")
    public suspend fun partitionKeys(argument: suspend CassandraPartitionKeyArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(CassandraPartitionKeyArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.partitionKeys = mapped
    }

    /**
     * @param values List of partition key.
     */
    @JvmName("dogixbyntglgftau")
    public suspend fun partitionKeys(vararg values: CassandraPartitionKeyArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.partitionKeys = mapped
    }

    internal fun build(): CassandraSchemaArgs = CassandraSchemaArgs(
        clusterKeys = clusterKeys,
        columns = columns,
        partitionKeys = partitionKeys,
    )
}
